Package: GeneralizedHyperbolic
Version: 0.8-7
Date: 2025-03-29
Title: The Generalized Hyperbolic Distribution
Authors@R: person(given = "David",
                  family = "Scott",
                  role = c("aut", "cre"),
                  email = "d.scott@auckland.ac.nz")
Maintainer: David Scott <d.scott@auckland.ac.nz>
Depends: R (>= 3.0.1)
Imports: DistributionUtils, MASS
Suggests: VarianceGamma, actuar, SkewHyperbolic, RUnit
Encoding: UTF-8
Description: Functions for the hyperbolic and related distributions.
  Density, distribution and quantile functions and random number
  generation are provided for the hyperbolic distribution, the
  generalized hyperbolic distribution, the generalized inverse
  Gaussian distribution and the skew-Laplace distribution. Additional
  functionality is provided for the hyperbolic distribution, normal
  inverse Gaussian distribution and generalized inverse Gaussian
  distribution, including fitting of these distributions to
  data. Linear models with hyperbolic errors may be fitted using
  hyperblmFit.
License: GPL (>= 2)
URL: https://r-forge.r-project.org/projects/rmetrics/
NeedsCompilation: no
Packaged: 2025-03-29 05:52:04 UTC; dsco0
Author: David Scott [aut, cre]
Repository: CRAN
Date/Publication: 2025-03-29 07:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 20:57:34 UTC; unix
