Package: GeneralizedHyperbolic
Version: 0.8-6
Date: 2023-11-26
Title: The Generalized Hyperbolic Distribution
Author: David Scott <d.scott@auckland.ac.nz>
Maintainer: David Scott <d.scott@auckland.ac.nz>
Depends: R (>= 3.0.1)
Imports: DistributionUtils, MASS
Suggests: VarianceGamma, actuar, SkewHyperbolic, RUnit
Encoding: UTF-8
Description: Functions for the hyperbolic and related distributions.
  Density, distribution and quantile functions and random number generation
  are provided for the hyperbolic distribution, the generalized hyperbolic
        distribution, the generalized inverse Gaussian distribution and
        the skew-Laplace distribution. Additional functionality is
        provided for the hyperbolic distribution, normal inverse
	Gaussian distribution and generalized inverse Gaussian distribution,
	including fitting of these distributions to data. Linear models with
        hyperbolic errors may be fitted using hyperblmFit.
License: GPL (>= 2)
URL: https://r-forge.r-project.org/projects/rmetrics/
NeedsCompilation: no
Packaged: 2023-11-26 08:08:04 UTC; dsco036
Repository: CRAN
Date/Publication: 2023-11-26 09:10:02 UTC
Built: R 4.4.0; ; 2024-04-28 11:56:24 UTC; unix
